==> hslua-cli-1.4.3-80.1-loong64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-EVG4JSevJmHEoZJGT6nGGe
key:                  hslua-cli-1.4.3-EVG4JSevJmHEoZJGT6nGGe
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  d896a8c7841ef49505b94eb6de3c4809
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-EVG4JSevJmHEoZJGT6nGGe
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-repl-0.1.2-3AaabvBDyUjK5jaey3qvPg
    lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ text-2.0.2 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hslua-cli-1.4.3-81-loong64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-cli
version:              1.4.3
visibility:           public
id:                   hslua-cli-1.4.3-B2pzl0Qll3T1Wp7voWtSXD
key:                  hslua-cli-1.4.3-B2pzl0Qll3T1Wp7voWtSXD
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  5e8df8f5b2739b2e7b73cf9bd45ab0ff
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-cli-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.3-B2pzl0Qll3T1Wp7voWtSXD
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-repl-0.1.2-JqaljPjGfM4G6LZEBISSdW
    lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9 text-2.0.2 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
